using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using VTGOApi;



namespace TestAPI_CSharp
{
    public partial class Form1 : Form
    {
        VTGOApi.clsVTGO oVTGO;

        enum StationCallState
        {
            TsIdle = 0,
            TsOffHook = 1,
            TsOnHook = 2,
            TsRingOut = 3,
            TsRingIn = 4,
            TsConnected = 5,
            TsBusy = 6,
            TsCongestion = 7,
            TsHold = 8,
            TsCallWaiting = 9,
            TsCallTransfer = 10,
            TsCallPark = 11,
            TsProceed = 12,
            TsCallRemoteMultiline = 13,
            TsInvalidNumber = 14
        } ;

        bool m_bRingingCall;
        int m_nRingingCallRef;



        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            m_bRingingCall = false;
            m_nRingingCallRef = 0;

            oVTGO = new VTGOApi.clsVTGO();

            oVTGO.PeerConnected += new __clsVTGO_PeerConnectedEventHandler(oVTGOEvent_PeerConnected);
            oVTGO.PeerLost += new __clsVTGO_PeerLostEventHandler(oVTGOEvent_PeerLost);
            oVTGO.StationRegister += new __clsVTGO_StationRegisterEventHandler(oVTGOEvent_StationRegister);
            oVTGO.LineUpdate += new __clsVTGO_LineUpdateEventHandler(oVTGOEvent_LineUpdate);
            oVTGO.IncomingCall += new __clsVTGO_IncomingCallEventHandler(oVTGOEvent_IncomingCall);
            oVTGO.DestinationHangUp += new __clsVTGO_DestinationHangUpEventHandler(oVTGOEvent_DestinationHangUp);
        }

        private void cmdRunProgram_Click(object sender, EventArgs e)
        {
            oVTGO.RunProgram();
        }
       
        private void cmdMakeCall_Click(object sender, EventArgs e)
        {
            oVTGO.MakeCall(txtDestination.Text);
        }

        private void cmdAnswer_Click(object sender, EventArgs e)
        {
            if (m_bRingingCall)
            {
                oVTGO.AnswerCall(m_nRingingCallRef);
            }
        }

        private void cmdHangup_Click(object sender, EventArgs e)
        {
             oVTGO.EndCall();
        }
        



        private void oVTGOEvent_PeerConnected()
        {
           WriteTrace("Event: Connected to softphone");
        }

        private void oVTGOEvent_PeerLost()
        {
            WriteTrace("Event: Disconnected from softphone");
        }

        void oVTGOEvent_StationRegister(bool bResult)
        {
            string sDescription = "";
            if (bResult)
                sDescription = "Event : Connected to CallManager";
            else
                sDescription = "Event : Disconnected from CallManager";

            WriteTrace(sDescription);
        }


        private void oVTGOEvent_LineUpdate(int sLineRef, int nCallRef, string sLineLabel, string sLineNumber, int nState, string sOtherParty, int nOrigin, int nMWI, int nButton)
        {
            string sDescription = "";
            sDescription += ("Event: Line Update - ");
            sDescription += ("  LineRef:" + sLineRef.ToString());
            sDescription += (", CallRef:" + nCallRef.ToString());
            sDescription += (", LineLabel:" + sLineLabel.ToString());
            sDescription += (", LineNumber:" + sLineNumber.ToString());
            sDescription += (", State:" + nState.ToString() + "(" + GetStateDescription(nState) + ")");
            sDescription += (", Origin:" + nOrigin.ToString() + "(" + GetCallOriginDescription(nOrigin) + ")");
            sDescription += (", MWI:" + nMWI.ToString());
            sDescription += (", Button:" + nButton.ToString());

            WriteTrace(sDescription);

            if (nCallRef == m_nRingingCallRef)
            {
                if (nState != (int)StationCallState.TsRingIn)
                {
                    //this call is not in ringing state anymore
                    m_bRingingCall = false;
                    m_nRingingCallRef = 0;
                }
            }
        }
        
        void oVTGOEvent_DestinationHangUp(int nCallRefId)
        {
            string sDescription = "";
            sDescription += ("Event: Call Terminated - ");
            sDescription += ("  nCallRefId:" + nCallRefId.ToString());
            WriteTrace(sDescription);
        }


        private void oVTGOEvent_IncomingCall(int nCallRef, string sLine, string sCallerId)
        {
            string sDescription = "";
            sDescription += ("Event: Incoming call - ");
            sDescription += ("  CallRef:" + nCallRef.ToString());
            sDescription += (", Line:" + sLine.ToString());
            sDescription += (", CallerId:" + sCallerId.ToString());

            m_bRingingCall = true;
            m_nRingingCallRef = nCallRef;

            WriteTrace(sDescription);
        }

       
        private string GetStateDescription(int nStateID)
        {
                StationCallState nState = (StationCallState)nStateID;
                switch (nState)
	            {
		            case StationCallState.TsIdle:               return "TsIdle";
		            case StationCallState.TsOffHook:	        return "TsOffHook";
		            case StationCallState.TsOnHook:				return "TsOnHook";
		            case StationCallState.TsRingOut:			return "TsRingOut";
		            case StationCallState.TsRingIn:				return "TsRingIn";
		            case StationCallState.TsConnected:			return "TsConnected";
		            case StationCallState.TsBusy:				return "TsBusy";
		            case StationCallState.TsCongestion:			return "TsCongestion";
		            case StationCallState.TsHold:				return "TsHold";
		            case StationCallState.TsCallWaiting:		return "TsCallWaiting";
		            case StationCallState.TsCallTransfer:		return "TsCallTransfer";
		            case StationCallState.TsCallPark:			return "TsCallPark";
		            case StationCallState.TsProceed:			return "TsProceed";
		            case StationCallState.TsCallRemoteMultiline:return "TsCallRemoteMultiline";
		            case StationCallState.TsInvalidNumber:		return "TsInvalidNumber";
	            }
	            return "";
        }

        private string GetCallOriginDescription(int nOriginID)
        {
            switch (nOriginID)
            {
                case 0: return "incoming";
                case 1: return "outgoing";
                case 2: return "incoming";
                case 3: return "incoming";
            }
            return "";
        }

        private void WriteTrace(string st)
        {
            lstEvents.Items.Insert(lstEvents.Items.Count, st); //add to list
            lstEvents.SetSelected(lstEvents.Items.Count - 1, true); //ensure item visible 
        }
 
    }
}